==> haskell-neat-interpolation-0.3.2.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: neat-interpolation
version: 0.3.2.1
id: neat-interpolation-0.3.2.1-E1KxGEWLEI521ApFT4jrXc
key: neat-interpolation-0.3.2.1-E1KxGEWLEI521ApFT4jrXc
license: MIT
copyright: (c) 2013, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/neat-interpolation
synopsis: A quasiquoter for neat and simple multiline text interpolation
description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.
category: String, QuasiQoutes
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    NeatInterpolation
hidden-modules: NeatInterpolation.Parsing NeatInterpolation.String
abi: aa17c02a37f85d11a6790d1323fd20b2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/neat-interpolation-0.3.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/neat-interpolation-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/neat-interpolation-0.3.2.1
hs-libraries: HSneat-interpolation-0.3.2.1-E1KxGEWLEI521ApFT4jrXc
depends:
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap template-haskell-2.12.0.0
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm base-4.10.1.0
abi-depends: text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap=e5bced146b6517b43ed5d06001479bde
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=3e78347d5a15e89f4fb1084b18368182
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock
haddock-html: /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-neat-interpolation-0.3.2.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: neat-interpolation
version: 0.3.2.1
id: neat-interpolation-0.3.2.1-FJUOq4r7zrKIJGRJY3MrQl
key: neat-interpolation-0.3.2.1-FJUOq4r7zrKIJGRJY3MrQl
license: MIT
copyright: (c) 2013, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/neat-interpolation
synopsis: A quasiquoter for neat and simple multiline text interpolation
description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.
category: String, QuasiQoutes
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    NeatInterpolation
hidden-modules: NeatInterpolation.Parsing NeatInterpolation.String
abi: 98af76cfd1f3ae20ba0b76a1e61c6b82
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/neat-interpolation-0.3.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/neat-interpolation-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/neat-interpolation-0.3.2.1
hs-libraries: HSneat-interpolation-0.3.2.1-FJUOq4r7zrKIJGRJY3MrQl
depends:
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp template-haskell-2.12.0.0
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm base-4.10.1.0
abi-depends: text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=3e78347d5a15e89f4fb1084b18368182
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock
haddock-html: /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
